function p = approxcirc(xx,yy)
% APPROXCIRC - Approximate inverse radius of circle fit
%    invr = APPROXCIRC(xx,yy) finds the approximate radius of a circle with
%    the points (XX,YY) on its circumference.
%    The result is signed: if the points (XX,YY) describe the circle in
%    anti-clockwise direction, INVR will be positive, else negative.
% 
%  CAUTION: The algorithm is approximate, because for very small INVR, 
%    i.e., when the circle is very large, fitting a proper circle (X0,Y0,R) 
%    is numerically challenging. So, instead, I assume that the points are
%    equally spaced, and fit XX and YY indepedently as quadratics in t=1..N,
%    where N is the number of points, and define the circle based on declaring
%    that the points (xfit,yfit)(1), (xfit,yfit)(N), and (xfit,yfit)((N+1)/2)
%    lie on the circle.

N=length(xx);
tt=[1:N]; tt=tt-mean(tt);
tt=tt/max(tt);

px = polyfit(tt(:),xx(:),2);
py = polyfit(tt(:),yy(:),2);

pr = sqrt(px.^2+py.^2);

p = 2*pr(1) / (pr(1)^2 + pr(2)^2);

x0 = px(3);
y0 = py(3);
xm = px(1) - px(2) + px(3);
ym = py(1) - py(2) + py(3);
xp = px(1) + px(2) + px(3);
yp = py(1) + py(2) + py(3);

ap = atan2(yp-y0,xp-x0);
am = atan2(y0-ym,x0-xm);
da = mod(ap-am,2*pi);

if da>=pi
  p=-p;
end
